@@ -24,7 +24,7 @@ import aiohttp.abc
 import yaml
 from aiohttp_socks import ProxyConnector
 
-__version__ = "0.3.0"
+__version__ = "0.3.1"
 __author__ = "Sergey M"
 
 # При запуске отладчика VS Code устанавливает переменную PYDEVD_USE_FRAME_EVAL=NO
@@ -309,11 +309,12 @@ class Scanner:
     output: typing.TextIO = sys.stdout
     workers_num: int = 10
     timeout: int | float | aiohttp.ClientTimeout = 30
-    delay: float = 0.02
+    delay: float = 0.05
     max_host_error: int = 10
     proxy_url: str | None = None
     # proxy_timeout: int | float = 10
     ignore_hosts: set[str] = dataclasses.field(default_factory=set)
+    follow_redirects: bool = False
 
     def __post_init__(self) -> None:
         self.lock = asyncio.Lock()
@@ -345,11 +346,14 @@ class Scanner:
     async def produce(self, urls: typing.Iterable[str]) -> None:
         for url in urls:
             # hostname всегда в нижнем регистре
-            if self.is_ignored_host(urllib.parse.urlsplit(url).hostname):
-                log.debug(f"skip ignored host url: {url}")
-                continue
+            try:
+                if self.is_ignored_host(urllib.parse.urlsplit(url).hostname):
+                    log.debug(f"skip ignored host url: {url}")
+                    continue
 
-            await self.queue.put(url)
+                await self.queue.put(url)
+            except BaseException as ex:
+                log.exception(ex)
 
     async def worker(self) -> None:
         task_name = asyncio.current_task().get_name()
@@ -367,9 +371,14 @@ class Scanner:
 
                 # Для каждого url используем новую сессию из-за того, что сессии
                 # со временем начинают тормозить
+                # root_url = urllib.parse.urljoin(url, "/")
                 async with self.get_session(
                     user_agent=user_agent,
                     proxy_url=self.proxy_url,
+                    # headers={
+                    #     "Origin": root_url[:-1],
+                    #     "Referer": root_url
+                    # },
                 ) as session:
                     probe_tasks = []
                     for probe in self.probes:
@@ -619,7 +628,7 @@ class Scanner:
             data=probe.get("data"),
             json=probe.get("json"),
             cookies=probe.get("cookies"),
-            allow_redirects=False,
+            allow_redirects=self.follow_redirects,
         )
 
         log.debug(
@@ -742,6 +751,7 @@ class Scanner:
         *,
         user_agent: str | None = None,
         proxy_url: str | None = None,
+        headers: dict[str, str] = {},
         **kwargs: typing.Any,
     ) -> typing.AsyncIterator[aiohttp.ClientSession]:
         connector = (
@@ -760,8 +770,10 @@ class Scanner:
                     "Accept": HEADER_ACCEPT,
                     "Accept-Language": HEADER_ACCEPT_LANGUAGE,
                     "Referer": GOOGLE_REFERER,
-                    "Upgrade-Insecure-Requests": "1",
+                    # перебрасывает с http:// на https://
+                    # "Upgrade-Insecure-Requests": "1",
                     "User-Agent": user_agent or DEFAULT_USER_AGENT,
+                    **headers,
                 }
             )
             yield session
@@ -823,6 +835,7 @@ class NameSpace(argparse.Namespace):
     delay: int | float
     max_host_error: int
     proxy_url: str
+    follow_redirects: bool
     verbosity: int
 
 
@@ -877,18 +890,22 @@ def parse_args(
         type=int,
         default=20,
     )
-    parser.add_argument("-t", "--timeout", help="total timeout", type=float)
+    parser.add_argument("-t", "--timeout", help="total timeout sec", type=float)
     parser.add_argument(
-        "-rt",
+        "-r",
         "--read-timeout",
-        help="socket read timeout",
+        "--socket-read",
+        "--read",
+        help="socket read timeout sec",
         type=float,
         default=5.0,
     )
     parser.add_argument(
-        "-ct",
+        "-C",
         "--connect-timeout",
-        help="socket read timeout",
+        "--socket-connect",
+        "--connect",
+        help="socket read timeout sec",
         type=float,
         default=10.0,
     )
@@ -901,9 +918,9 @@ def parse_args(
     parser.add_argument(
         "-d",
         "--delay",
-        help="delay before each request in seconds",
-        type=float,
-        default=0.12,
+        help="delay in milliseconds",
+        type=int,
+        default=120,
     )
     parser.add_argument(
         "-maxhe",
@@ -915,7 +932,14 @@ def parse_args(
     parser.add_argument(
         "--proxy-url",
         "--proxy",
-        help="proxy url, eg `socks5://localhost:1080`",
+        help="proxy url, e.g. socks5://localhost:1080",
+    )
+    parser.add_argument(
+        "-f",
+        "--follow-redirects",
+        help="follow redirects",
+        action=argparse.BooleanOptionalAction,
+        default=False,
     )
     parser.add_argument(
         "-v",
@@ -984,10 +1008,11 @@ def main(argv: typing.Sequence[str] | None = None) -> None | int:
         output=args.output,
         timeout=timeout,
         workers_num=conf.get("workers_num", args.workers_num),
-        delay=conf.get("delay", args.delay),
+        delay=conf.get("delay", args.delay) / 1000,
         ignore_hosts=conf.get("ignore_hosts", ignore_hosts),
         max_host_error=conf.get("max_host_error", args.max_host_error),
         proxy_url=conf.get("proxy_url", args.proxy_url),
+        follow_redirects=conf.get("follow_redirects", args.follow_redirects),
         # proxy_timeout=conf.get("proxy_timeout", args.proxy_timeout),
     )
 
